/*
@version: 0.2
@author: Sudheer K. <scifi.guy@hotmail.com>
@license: GNU General Public License
*/

#ifndef GCONFUTILITY_H
#define GCONFUTILITY_H

#include <QObject>
#include <gconf/gconf-client.h>

#define APPLICATION_NAME "vicar"
#define GCONF_DIR "/apps/Maemo/" APPLICATION_NAME "/"

class GConfUtility : public QObject
 {
Q_OBJECT
public:
    GConfUtility(QObject *parent = 0);
    ~GConfUtility();
    void setGconfValueString(QString strKey,QString strValue);
    QString getGconfValueString(QString strKey);

    void setGconfValueBoolean(QString strKey,bool boolValue);
    bool getGconfValueBoolean(QString strKey);

    void setGconfValueInteger(QString strKey,int intValue);
    int getGconfValueInteger(QString strKey);

private:
     GConfClient *gconfClient;
};

#endif // GCONFUTILITY_H
